==> ejc-middlemeasurement-impl-3.0.0-20221201.064926-249-sources.jar: com/ejianc/business/middlemeasurement/bean/MechanicalleasedetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度机械设备租赁单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_mechanicalleasedetail")
public class MechanicalleasedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="name")
    private java.lang.String name; // 租赁物资名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="lease_num")
    private java.math.BigDecimal leaseNum; // 租赁数量
    @TableField(value="billing_start_time")
    private java.util.Date billingStartTime; // 本期计算起始日期
    @TableField(value="billing_end_time")
    private java.util.Date billingEndTime; // 本期计算终止日期
    @TableField(value="lease_days_this_time")
    private java.lang.Integer leaseDaysThisTime; // 本期租赁期长（天）
    @TableField(value="lose_destroy_num")
    private java.lang.Integer loseDestroyNum; // 丢失损坏量
    @TableField(value="in_tax_lease_unit")
    private java.math.BigDecimal inTaxLeaseUnit; // 租赁单价（含税）（元）
    @TableField(value="ex_tax_lease_unit")
    private java.math.BigDecimal exTaxLeaseUnit; // 租赁单价（除税）（元）
    @TableField(value="in_tax_lease_total")
    private java.math.BigDecimal inTaxLeaseTotal; // 租赁合价（含税）（元）
    @TableField(value="ex_tax_lease_total")
    private java.math.BigDecimal exTaxLeaseTotal; // 租赁合价（除税）（元）
    @TableField(value="in_tax_compensation_unit")
    private java.math.BigDecimal inTaxCompensationUnit; // 赔偿单价（含税）（元）
    @TableField(value="ex_tax_compensation_unit")
    private java.math.BigDecimal exTaxCompensationUnit; // 赔偿单价（除税）（元）
    @TableField(value="in_tax_compensation_amount")
    private java.math.BigDecimal inTaxCompensationAmount; // 赔偿合价（含税）（元）
    @TableField(value="ex_tax_compensation_amount")
    private java.math.BigDecimal exTaxCompensationAmount; // 赔偿合价（除税）（元）
    @TableField(value="in_tax_maintain")
    private java.math.BigDecimal inTaxMaintain; // 清理维修费等其他费用（含税）（元）
    @TableField(value="ex_tax_maintain")
    private java.math.BigDecimal exTaxMaintain; // 清理维修费等其他费用（除税）（元）
    @TableField(value="in_tax_settlement_month")
    private java.math.BigDecimal inTaxSettlementMonth; // 月度结算费用（含税）（元）
    @TableField(value="ex_tax_settlement_month")
    private java.math.BigDecimal exTaxSettlementMonth; // 月度结算费用（除税）（元）
    @TableField(value="ex_tax_cumulative")
    private java.math.BigDecimal exTaxCumulative; // 累计结算金额(除税)
    @TableField(value="in_tax_cumulative")
    private java.math.BigDecimal inTaxCumulative; // 累计结算金额(含税)
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="category_id")
    private java.lang.Long categoryId; // 分类id
    @TableField(value="category_name")
    private java.lang.String categoryName; // 分类名称
    @TableField(value="category_code")
    private java.lang.String categoryCode; // 分类编码
    @TableField(value="equipment_code")
    private java.lang.String equipmentCode; // 设备编码
    @TableField(value="payment_proportion")
    private java.math.BigDecimal paymentProportion; //付款比例
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="settlement_time")
    private java.util.Date settlementTime; // 结算时间

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getSettlementTime() {
        return settlementTime;
    }

    public void setSettlementTime(Date settlementTime) {
        this.settlementTime = settlementTime;
    }

    public BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    public void setPaymentProportion(BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 租赁物资名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 租赁物资名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 租赁数量
     */
    public java.math.BigDecimal getLeaseNum() {
        return leaseNum;
    }

    /**
     * 租赁数量
     */
    public void setLeaseNum(java.math.BigDecimal leaseNum) {
        this.leaseNum = leaseNum;
    }
    /**
     * 本期计算起始日期
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 本期计算起始日期
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 本期计算终止日期
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 本期计算终止日期
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 本期租赁期长（天）
     */
    public java.lang.Integer getLeaseDaysThisTime() {
        return leaseDaysThisTime;
    }

    /**
     * 本期租赁期长（天）
     */
    public void setLeaseDaysThisTime(java.lang.Integer leaseDaysThisTime) {
        this.leaseDaysThisTime = leaseDaysThisTime;
    }
    /**
     * 丢失损坏量
     */
    public java.lang.Integer getLoseDestroyNum() {
        return loseDestroyNum;
    }

    /**
     * 丢失损坏量
     */
    public void setLoseDestroyNum(java.lang.Integer loseDestroyNum) {
        this.loseDestroyNum = loseDestroyNum;
    }
    /**
     * 租赁单价（含税）（元）
     */
    public java.math.BigDecimal getInTaxLeaseUnit() {
        return inTaxLeaseUnit;
    }

    /**
     * 租赁单价（含税）（元）
     */
    public void setInTaxLeaseUnit(java.math.BigDecimal inTaxLeaseUnit) {
        this.inTaxLeaseUnit = inTaxLeaseUnit;
    }
    /**
     * 租赁单价（除税）（元）
     */
    public java.math.BigDecimal getExTaxLeaseUnit() {
        return exTaxLeaseUnit;
    }

    /**
     * 租赁单价（除税）（元）
     */
    public void setExTaxLeaseUnit(java.math.BigDecimal exTaxLeaseUnit) {
        this.exTaxLeaseUnit = exTaxLeaseUnit;
    }
    /**
     * 租赁合价（含税）（元）
     */
    public java.math.BigDecimal getInTaxLeaseTotal() {
        return inTaxLeaseTotal;
    }

    /**
     * 租赁合价（含税）（元）
     */
    public void setInTaxLeaseTotal(java.math.BigDecimal inTaxLeaseTotal) {
        this.inTaxLeaseTotal = inTaxLeaseTotal;
    }
    /**
     * 租赁合价（除税）（元）
     */
    public java.math.BigDecimal getExTaxLeaseTotal() {
        return exTaxLeaseTotal;
    }

    /**
     * 租赁合价（除税）（元）
     */
    public void setExTaxLeaseTotal(java.math.BigDecimal exTaxLeaseTotal) {
        this.exTaxLeaseTotal = exTaxLeaseTotal;
    }
    /**
     * 赔偿单价（含税）（元）
     */
    public java.math.BigDecimal getInTaxCompensationUnit() {
        return inTaxCompensationUnit;
    }

    /**
     * 赔偿单价（含税）（元）
     */
    public void setInTaxCompensationUnit(java.math.BigDecimal inTaxCompensationUnit) {
        this.inTaxCompensationUnit = inTaxCompensationUnit;
    }
    /**
     * 赔偿单价（除税）（元）
     */
    public java.math.BigDecimal getExTaxCompensationUnit() {
        return exTaxCompensationUnit;
    }

    /**
     * 赔偿单价（除税）（元）
     */
    public void setExTaxCompensationUnit(java.math.BigDecimal exTaxCompensationUnit) {
        this.exTaxCompensationUnit = exTaxCompensationUnit;
    }
    /**
     * 赔偿合价（含税）（元）
     */
    public java.math.BigDecimal getInTaxCompensationTotal() {
        return inTaxCompensationAmount;
    }

    /**
     * 赔偿合价（含税）（元）
     */
    public void setInTaxCompensationTotal(java.math.BigDecimal inTaxCompensationTotal) {
        this.inTaxCompensationAmount = inTaxCompensationTotal;
    }
    /**
     * 赔偿合价（除税）（元）
     */
    public java.math.BigDecimal getExTaxCompensationTotal() {
        return exTaxCompensationAmount;
    }

    /**
     * 赔偿合价（除税）（元）
     */
    public void setExTaxCompensationTotal(java.math.BigDecimal exTaxCompensationTotal) {
        this.exTaxCompensationAmount = exTaxCompensationTotal;
    }
    /**
     * 清理维修费等其他费用（含税）（元）
     */
    public java.math.BigDecimal getInTaxMaintain() {
        return inTaxMaintain;
    }

    /**
     * 清理维修费等其他费用（含税）（元）
     */
    public void setInTaxMaintain(java.math.BigDecimal inTaxMaintain) {
        this.inTaxMaintain = inTaxMaintain;
    }
    /**
     * 清理维修费等其他费用（除税）（元）
     */
    public java.math.BigDecimal getExTaxMaintain() {
        return exTaxMaintain;
    }

    /**
     * 清理维修费等其他费用（除税）（元）
     */
    public void setExTaxMaintain(java.math.BigDecimal exTaxMaintain) {
        this.exTaxMaintain = exTaxMaintain;
    }
    /**
     * 月度结算费用（含税）（元）
     */
    public java.math.BigDecimal getInTaxSettlementMonth() {
        return inTaxSettlementMonth;
    }

    /**
     * 月度结算费用（含税）（元）
     */
    public void setInTaxSettlementMonth(java.math.BigDecimal inTaxSettlementMonth) {
        this.inTaxSettlementMonth = inTaxSettlementMonth;
    }
    /**
     * 月度结算费用（除税）（元）
     */
    public java.math.BigDecimal getExTaxSettlementMonth() {
        return exTaxSettlementMonth;
    }

    /**
     * 月度结算费用（除税）（元）
     */
    public void setExTaxSettlementMonth(java.math.BigDecimal exTaxSettlementMonth) {
        this.exTaxSettlementMonth = exTaxSettlementMonth;
    }
    /**
     * 累计结算金额(除税)
     */
    public java.math.BigDecimal getExTaxCumulative() {
        return exTaxCumulative;
    }

    /**
     * 累计结算金额(除税)
     */
    public void setExTaxCumulative(java.math.BigDecimal exTaxCumulative) {
        this.exTaxCumulative = exTaxCumulative;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getInTaxCumulative() {
        return inTaxCumulative;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setInTaxCumulative(java.math.BigDecimal inTaxCumulative) {
        this.inTaxCumulative = inTaxCumulative;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public BigDecimal getInTaxCompensationAmount() {
        return inTaxCompensationAmount;
    }

    public void setInTaxCompensationAmount(BigDecimal inTaxCompensationAmount) {
        this.inTaxCompensationAmount = inTaxCompensationAmount;
    }

    public BigDecimal getExTaxCompensationAmount() {
        return exTaxCompensationAmount;
    }

    public void setExTaxCompensationAmount(BigDecimal exTaxCompensationAmount) {
        this.exTaxCompensationAmount = exTaxCompensationAmount;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/bean/MechanicalleasedetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度机械设备租赁单子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_mechanicalleasedetail")
public class MechanicalleasedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="name")
    private java.lang.String name; // 租赁物资名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="lease_num")
    private java.math.BigDecimal leaseNum; // 租赁数量
    @TableField(value="billing_start_time")
    private java.util.Date billingStartTime; // 本期计算起始日期
    @TableField(value="billing_end_time")
    private java.util.Date billingEndTime; // 本期计算终止日期
    @TableField(value="lease_days_this_time")
    private BigDecimal leaseDaysThisTime; // 本期租赁期长（天）
    @TableField(value="lose_destroy_num")
    private java.lang.Integer loseDestroyNum; // 丢失损坏量
    @TableField(value="in_tax_lease_unit")
    private java.math.BigDecimal inTaxLeaseUnit; // 租赁单价（含税）（元）
    @TableField(value="ex_tax_lease_unit")
    private java.math.BigDecimal exTaxLeaseUnit; // 租赁单价（除税）（元）
    @TableField(value="in_tax_lease_total")
    private java.math.BigDecimal inTaxLeaseTotal; // 租赁合价（含税）（元）
    @TableField(value="ex_tax_lease_total")
    private java.math.BigDecimal exTaxLeaseTotal; // 租赁合价（除税）（元）
    @TableField(value="in_tax_compensation_unit")
    private java.math.BigDecimal inTaxCompensationUnit; // 赔偿单价（含税）（元）
    @TableField(value="ex_tax_compensation_unit")
    private java.math.BigDecimal exTaxCompensationUnit; // 赔偿单价（除税）（元）
    @TableField(value="in_tax_compensation_amount")
    private java.math.BigDecimal inTaxCompensationAmount; // 赔偿合价（含税）（元）
    @TableField(value="ex_tax_compensation_amount")
    private java.math.BigDecimal exTaxCompensationAmount; // 赔偿合价（除税）（元）
    @TableField(value="in_tax_maintain")
    private java.math.BigDecimal inTaxMaintain; // 清理维修费等其他费用（含税）（元）
    @TableField(value="ex_tax_maintain")
    private java.math.BigDecimal exTaxMaintain; // 清理维修费等其他费用（除税）（元）
    @TableField(value="in_tax_settlement_month")
    private java.math.BigDecimal inTaxSettlementMonth; // 月度结算费用（含税）（元）
    @TableField(value="ex_tax_settlement_month")
    private java.math.BigDecimal exTaxSettlementMonth; // 月度结算费用（除税）（元）
    @TableField(value="ex_tax_cumulative")
    private java.math.BigDecimal exTaxCumulative; // 累计结算金额(除税)
    @TableField(value="in_tax_cumulative")
    private java.math.BigDecimal inTaxCumulative; // 累计结算金额(含税)
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="category_id")
    private java.lang.Long categoryId; // 分类id
    @TableField(value="category_name")
    private java.lang.String categoryName; // 分类名称
    @TableField(value="category_code")
    private java.lang.String categoryCode; // 分类编码
    @TableField(value="equipment_code")
    private java.lang.String equipmentCode; // 设备编码
    @TableField(value="payment_proportion")
    private java.math.BigDecimal paymentProportion; //付款比例
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="settlement_time")
    private java.util.Date settlementTime; // 结算时间

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getSettlementTime() {
        return settlementTime;
    }

    public void setSettlementTime(Date settlementTime) {
        this.settlementTime = settlementTime;
    }

    public BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    public void setPaymentProportion(BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 租赁物资名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 租赁物资名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 租赁数量
     */
    public java.math.BigDecimal getLeaseNum() {
        return leaseNum;
    }

    /**
     * 租赁数量
     */
    public void setLeaseNum(java.math.BigDecimal leaseNum) {
        this.leaseNum = leaseNum;
    }
    /**
     * 本期计算起始日期
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 本期计算起始日期
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 本期计算终止日期
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 本期计算终止日期
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 本期租赁期长（天）
     */
    public BigDecimal getLeaseDaysThisTime() {
        return leaseDaysThisTime;
    }

    /**
     * 本期租赁期长（天）
     */
    public void setLeaseDaysThisTime(BigDecimal leaseDaysThisTime) {
        this.leaseDaysThisTime = leaseDaysThisTime;
    }
    /**
     * 丢失损坏量
     */
    public java.lang.Integer getLoseDestroyNum() {
        return loseDestroyNum;
    }

    /**
     * 丢失损坏量
     */
    public void setLoseDestroyNum(java.lang.Integer loseDestroyNum) {
        this.loseDestroyNum = loseDestroyNum;
    }
    /**
     * 租赁单价（含税）（元）
     */
    public java.math.BigDecimal getInTaxLeaseUnit() {
        return inTaxLeaseUnit;
    }

    /**
     * 租赁单价（含税）（元）
     */
    public void setInTaxLeaseUnit(java.math.BigDecimal inTaxLeaseUnit) {
        this.inTaxLeaseUnit = inTaxLeaseUnit;
    }
    /**
     * 租赁单价（除税）（元）
     */
    public java.math.BigDecimal getExTaxLeaseUnit() {
        return exTaxLeaseUnit;
    }

    /**
     * 租赁单价（除税）（元）
     */
    public void setExTaxLeaseUnit(java.math.BigDecimal exTaxLeaseUnit) {
        this.exTaxLeaseUnit = exTaxLeaseUnit;
    }
    /**
     * 租赁合价（含税）（元）
     */
    public java.math.BigDecimal getInTaxLeaseTotal() {
        return inTaxLeaseTotal;
    }

    /**
     * 租赁合价（含税）（元）
     */
    public void setInTaxLeaseTotal(java.math.BigDecimal inTaxLeaseTotal) {
        this.inTaxLeaseTotal = inTaxLeaseTotal;
    }
    /**
     * 租赁合价（除税）（元）
     */
    public java.math.BigDecimal getExTaxLeaseTotal() {
        return exTaxLeaseTotal;
    }

    /**
     * 租赁合价（除税）（元）
     */
    public void setExTaxLeaseTotal(java.math.BigDecimal exTaxLeaseTotal) {
        this.exTaxLeaseTotal = exTaxLeaseTotal;
    }
    /**
     * 赔偿单价（含税）（元）
     */
    public java.math.BigDecimal getInTaxCompensationUnit() {
        return inTaxCompensationUnit;
    }

    /**
     * 赔偿单价（含税）（元）
     */
    public void setInTaxCompensationUnit(java.math.BigDecimal inTaxCompensationUnit) {
        this.inTaxCompensationUnit = inTaxCompensationUnit;
    }
    /**
     * 赔偿单价（除税）（元）
     */
    public java.math.BigDecimal getExTaxCompensationUnit() {
        return exTaxCompensationUnit;
    }

    /**
     * 赔偿单价（除税）（元）
     */
    public void setExTaxCompensationUnit(java.math.BigDecimal exTaxCompensationUnit) {
        this.exTaxCompensationUnit = exTaxCompensationUnit;
    }
    /**
     * 赔偿合价（含税）（元）
     */
    public java.math.BigDecimal getInTaxCompensationTotal() {
        return inTaxCompensationAmount;
    }

    /**
     * 赔偿合价（含税）（元）
     */
    public void setInTaxCompensationTotal(java.math.BigDecimal inTaxCompensationTotal) {
        this.inTaxCompensationAmount = inTaxCompensationTotal;
    }
    /**
     * 赔偿合价（除税）（元）
     */
    public java.math.BigDecimal getExTaxCompensationTotal() {
        return exTaxCompensationAmount;
    }

    /**
     * 赔偿合价（除税）（元）
     */
    public void setExTaxCompensationTotal(java.math.BigDecimal exTaxCompensationTotal) {
        this.exTaxCompensationAmount = exTaxCompensationTotal;
    }
    /**
     * 清理维修费等其他费用（含税）（元）
     */
    public java.math.BigDecimal getInTaxMaintain() {
        return inTaxMaintain;
    }

    /**
     * 清理维修费等其他费用（含税）（元）
     */
    public void setInTaxMaintain(java.math.BigDecimal inTaxMaintain) {
        this.inTaxMaintain = inTaxMaintain;
    }
    /**
     * 清理维修费等其他费用（除税）（元）
     */
    public java.math.BigDecimal getExTaxMaintain() {
        return exTaxMaintain;
    }

    /**
     * 清理维修费等其他费用（除税）（元）
     */
    public void setExTaxMaintain(java.math.BigDecimal exTaxMaintain) {
        this.exTaxMaintain = exTaxMaintain;
    }
    /**
     * 月度结算费用（含税）（元）
     */
    public java.math.BigDecimal getInTaxSettlementMonth() {
        return inTaxSettlementMonth;
    }

    /**
     * 月度结算费用（含税）（元）
     */
    public void setInTaxSettlementMonth(java.math.BigDecimal inTaxSettlementMonth) {
        this.inTaxSettlementMonth = inTaxSettlementMonth;
    }
    /**
     * 月度结算费用（除税）（元）
     */
    public java.math.BigDecimal getExTaxSettlementMonth() {
        return exTaxSettlementMonth;
    }

    /**
     * 月度结算费用（除税）（元）
     */
    public void setExTaxSettlementMonth(java.math.BigDecimal exTaxSettlementMonth) {
        this.exTaxSettlementMonth = exTaxSettlementMonth;
    }
    /**
     * 累计结算金额(除税)
     */
    public java.math.BigDecimal getExTaxCumulative() {
        return exTaxCumulative;
    }

    /**
     * 累计结算金额(除税)
     */
    public void setExTaxCumulative(java.math.BigDecimal exTaxCumulative) {
        this.exTaxCumulative = exTaxCumulative;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getInTaxCumulative() {
        return inTaxCumulative;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setInTaxCumulative(java.math.BigDecimal inTaxCumulative) {
        this.inTaxCumulative = inTaxCumulative;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public BigDecimal getInTaxCompensationAmount() {
        return inTaxCompensationAmount;
    }

    public void setInTaxCompensationAmount(BigDecimal inTaxCompensationAmount) {
        this.inTaxCompensationAmount = inTaxCompensationAmount;
    }

    public BigDecimal getExTaxCompensationAmount() {
        return exTaxCompensationAmount;
    }

    public void setExTaxCompensationAmount(BigDecimal exTaxCompensationAmount) {
        this.exTaxCompensationAmount = exTaxCompensationAmount;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
}
